﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace RSN.DotP
{
	// This class represents a collection of filters and at the same time a filter
	//	itself, this is to allow for nested filters and a unified way to check a
	//	card regardless of how many filters there are.
	class CardFilterSet : CardFilterBase
	{
		private List<CardFilterBase> m_lstFilters;

		public CardFilterSet() : base()
		{
			m_lstFilters = new List<CardFilterBase>();
		}

		/*public List<CardFilterBase> Filters
		{
			get { return m_lstFilters; }
		}//*/

		public override string Name
		{
			get { return "Filter Set"; }
		}

		public override object Operation
		{
			get { return null; }
			set { /* Sets don't have an operation. */ }
		}

		public override object Value
		{
			get { return m_lstFilters; }
			set
			{
				if (value is List<CardFilterBase>)
					m_lstFilters = (List<CardFilterBase>)value;
			}
		}

		public override bool IsAllowed(CardInfo ciCard)
		{
			bool bPass = true;

			if (m_lstFilters.Count > 0)
			{
				bPass = m_lstFilters[0].IsAllowed(ciCard);
				FilterBooleanOperation eCompare = m_lstFilters[0].Compare;
				for (int i = 1; i < m_lstFilters.Count; i++)
				{
					CardFilterBase cfbFilter = m_lstFilters[i];
					switch (eCompare)
					{
						case FilterBooleanOperation.And:
							bPass &= cfbFilter.IsAllowed(ciCard);
							break;
						case FilterBooleanOperation.Or:
							bPass |= cfbFilter.IsAllowed(ciCard);
							break;
						default:
							// Ignore filters with invalid Compare values.
							break;
					}
					eCompare = cfbFilter.Compare;
				}
			}

			return bPass;
		}
	}
}
